@@ -6,8 +6,11 @@ __all__ = [
     "demtools",
     "utilities",
     "netcdf_utils",
+    "textfile_utils",
+    "kml_utils",
     "interptools",
     "mapping",
+    "lfsourceclass",
     "lfclass",
     "scripts",
 ]
