@@ -61,8 +61,10 @@ from lfmaptools.demtools import load_dem, load_hillshade
 from lfmaptools.epsg_defs import webmerc, wgs84
 from lfmaptools.geotools import EastingNorthing_TM, LatLon_TM, LatLon_TM_polygonize
 from lfmaptools.interptools import interp_weights, interpolate
+from lfmaptools.lfsourceclass import LFSource
 from lfmaptools.mapping import add_stamen_basemap
 from lfmaptools.netcdf_utils import nc2xr, nc_max, nc_min, nc_min_max, nc_vars
+from lfmaptools.textfile_utils import txt2xr
 from lfmaptools.utilities import (
     _decompress_gz,
     _nice_round,
@@ -453,41 +455,6 @@ def _get_LF_output_fmt(short_name, filetype="snapshot"):
     return ret
 
 
-class LFSource(object):
-    def __init__(
-        self,
-        x=None,
-        y=None,
-        lat=None,
-        lon=None,
-        radius=None,
-        time=None,
-        flux=None,
-        conc=None,
-    ):
-        self.x = x
-        self.y = y
-        self.lat = lat
-        self.lon = lon
-        self.radius = radius
-        self.time = time
-        self.flux = flux
-        self.conc = conc
-
-    def volume(self):
-        return np.trapz(self.flux, self.time)
-
-    def peak_flux(self):
-        return np.amax(self.flux)
-
-    def peak_time(self):
-        i = np.argmax(self.flux)
-        return self.time[i]
-
-    def duration(self):
-        return self.time[-1] - self.time[0]
-
-
 class LaharFlowData(object):
     def __init__(self, LaharFlowDir, zipped=False):
 
@@ -1135,18 +1102,8 @@ class LaharFlowData(object):
 
     def _get_data_txt(self, LaharFlowFile, vars=None):
         try:
-            data = pd.read_csv(
-                LaharFlowFile,
-                delimiter=",",
-                skipinitialspace=True,
-                index_col=["y_distance", "x_distance"],
-            )
 
-            if vars is not None:
-                drop_vars = [d for d in data.columns if d not in vars]
-                data.drop(columns=drop_vars, axis=1, inplace=True)
-
-            raster = xa.Dataset.from_dataframe(data)
+            raster = txt2xr(LaharFlowFile)
             raster = raster.rename({"x_distance": "x", "y_distance": "y"})
             raster["x"] = raster["x"] + self.utm[0]
             raster["y"] = raster["y"] + self.utm[1]
