@@ -1,6 +1,7 @@
 import ast
 import os
 import pathlib
+import sys
 import tempfile
 import zipfile
 
@@ -50,7 +51,7 @@ class PathPath(click.Path):
     ),
 )
 @click.option(
-    "-dest",
+    "-d",
     "--dest",
     "dest",
     type=PathPath(
@@ -62,6 +63,7 @@ class PathPath(click.Path):
     ),
     prompt="Set destination directory",
     default=os.getcwd(),
+    help="Destination directory",
 )
 @click.option(
     "-o",
@@ -70,6 +72,7 @@ class PathPath(click.Path):
     type=click.File(mode="w"),
     is_flag=False,
     flag_value=None,
+    help="Output filename",
 )
 @click.option(
     "-v",
@@ -77,8 +80,44 @@ class PathPath(click.Path):
     "var",
     type=click.STRING,
     multiple=True,
+    help="Variables to include in output file.  Multiple variables are allowed.",
 )
-def lf_to_gtif(src, input_file, dest, file_out, var):
+@click.option(
+    "--debug",
+    "debug",
+    is_flag=True,
+    help="Run in debug mode with traceback on error messages.",
+)
+def lf_to_gtif(src, input_file, dest, file_out, var, debug):
+    """Convert outputs from LaharFlow into geotiff files.
+
+    SRC is the name of the directory containing LaharFlow outputs, which can be a zipped folder.
+
+    INPUT_FILE is the name of a LaharFlow output file contained in SRC that will be converted to geotif.
+
+    \b
+    Example 1:
+        For the Maximums.nc file contained in a directory /home/in/
+        a geotif containing the maximum_depth and time_of_max_depth variables
+        called max_depth.tif can be created in the directoty /home/out/
+        using the command:
+
+    \b
+        lf_to_gtif -d /home/out/ -o max_depth.tif -v maximum_depth -v time_of_max_depth /home/in/ Maximums.nc
+
+    \b
+    Example 2:
+        For the 000001.nc file contained in a zipped folder /home/in/LF.zip
+        a geotif containing the flow_depth and flow_speed variables
+        called 000001.tif can be created in the directoty /home/out/
+        using the command:
+
+    \b
+        lf_to_gtif -d /home/out/ -o 000001.tif -v flow_depth -v flow_speed /home/in/LF.zip 000001.nc
+
+    """
+
+    sys.tracebacklimit = 1 if debug else 0
 
     if file_out is None:
         file_out = input_file.with_suffix(".tif")
@@ -98,7 +137,6 @@ def lf_to_gtif(src, input_file, dest, file_out, var):
     else:
         if type(var) is tuple:
             var = list(var)
-        # var = [var]
 
     if zipped:
         tmpdirname = tempfile.TemporaryDirectory()
@@ -124,6 +162,13 @@ def lf_to_gtif(src, input_file, dest, file_out, var):
     else:
         raise RuntimeError("result file not recognized")
 
+    if var is not None:
+        for v in var:
+            if v not in data.vars:
+                raise ValueError(
+                    f"variable {v} not in {result_file}.\n Allowed variables are {data.vars}"
+                )
+
     raster = data.to_xarray(vars=var)
 
     fileOut = os.path.join(dest.resolve(), file_out.name)
